From d491ac0865941cd94a0b8b463bbe4d3ccbd6be22 Mon Sep 17 00:00:00 2001
From: Max Wilfinger <6246609+maxwxyz@users.noreply.github.com>
Date: Mon, 4 Dec 2023 17:41:04 +0100
Subject: [PATCH] Renaming FEM mesh region to mesh refinement (only Users POV /
tooltips) (#11489)
* project to document on information, merge, util
* rename MehRegion to MeshRefinement (tooltip/user PoV only)
---
src/Mod/Fem/Gui/Resources/ui/MeshRegion.ui | 2 +-
src/Mod/Fem/ObjectsFem.py | 4 ++--
src/Mod/Fem/femcommands/commands.py | 6 +++---
src/Mod/Fem/femmesh/gmshtools.py | 14 +++++++-------
src/Mod/Fem/femobjects/mesh_gmsh.py | 2 +-
src/Mod/Fem/femobjects/mesh_region.py | 4 ++--
src/Mod/Fem/femtaskpanels/task_mesh_region.py | 4 ++--
7 files changed, 18 insertions(+), 18 deletions(-)
diff --git a/src/Mod/Fem/Gui/Resources/ui/MeshRegion.ui b/src/Mod/Fem/Gui/Resources/ui/MeshRegion.ui
index 402c36743e..5e646e3d03 100644
--- a/src/Mod/Fem/Gui/Resources/ui/MeshRegion.ui
+++ b/src/Mod/Fem/Gui/Resources/ui/MeshRegion.ui
@@ -11,7 +11,7 @@
- Mesh region
+ Mesh refinement
-
diff --git a/src/Mod/Fem/ObjectsFem.py b/src/Mod/Fem/ObjectsFem.py
index 2dd8d83b54..bae375407e 100644
--- a/src/Mod/Fem/ObjectsFem.py
+++ b/src/Mod/Fem/ObjectsFem.py
@@ -579,7 +579,7 @@ def makeMeshGroup(
name="MeshGroup"
):
"""makeMeshGroup(document, base_mesh, [use_label], [name]):
- creates a FEM mesh region object to define properties for a region of a FEM mesh"""
+ creates a FEM mesh refinement object to define properties for a region of a FEM mesh"""
obj = doc.addObject("Fem::FeaturePython", name)
from femobjects import mesh_group
mesh_group.MeshGroup(obj)
@@ -613,7 +613,7 @@ def makeMeshRegion(
name="MeshRegion"
):
"""makeMeshRegion(document, base_mesh, [element_length], [name]):
- creates a FEM mesh region object to define properties for a region of a FEM mesh"""
+ creates a FEM mesh refinement object to define properties for a refinement of a FEM mesh"""
obj = doc.addObject("Fem::FeaturePython", name)
from femobjects import mesh_region
mesh_region.MeshRegion(obj)
diff --git a/src/Mod/Fem/femcommands/commands.py b/src/Mod/Fem/femcommands/commands.py
index 08e5ece306..721dc1defe 100644
--- a/src/Mod/Fem/femcommands/commands.py
+++ b/src/Mod/Fem/femcommands/commands.py
@@ -991,17 +991,17 @@ class _MeshNetgenFromShape(CommandManager):
class _MeshRegion(CommandManager):
- "The FEM_MeshRegion command definition"
+ "The FEM_MeshRefinement command definition"
def __init__(self):
super(_MeshRegion, self).__init__()
self.menutext = Qt.QT_TRANSLATE_NOOP(
"FEM_MeshRegion",
- "FEM mesh region"
+ "FEM mesh refinement"
)
self.tooltip = Qt.QT_TRANSLATE_NOOP(
"FEM_MeshRegion",
- "Creates a FEM mesh region"
+ "Creates a FEM mesh refinement"
)
self.is_active = "with_gmsh_femmesh"
self.do_activated = "add_obj_on_gui_selobj_set_edit"
diff --git a/src/Mod/Fem/femobjects/mesh_gmsh.py b/src/Mod/Fem/femobjects/mesh_gmsh.py
index f34431f468..386a7ae638 100644
--- a/src/Mod/Fem/femobjects/mesh_gmsh.py
+++ b/src/Mod/Fem/femobjects/mesh_gmsh.py
@@ -119,7 +119,7 @@ class MeshGmsh(base_fempythonobject.BaseFemPythonObject):
"App::PropertyLinkList",
"MeshRegionList",
"Base",
- "Mesh regions of the mesh"
+ "Mesh refinments of the mesh"
)
obj.MeshRegionList = []
diff --git a/src/Mod/Fem/femobjects/mesh_region.py b/src/Mod/Fem/femobjects/mesh_region.py
index 067cee6c3e..195208fa03 100644
--- a/src/Mod/Fem/femobjects/mesh_region.py
+++ b/src/Mod/Fem/femobjects/mesh_region.py
@@ -46,12 +46,12 @@ class MeshRegion(base_fempythonobject.BaseFemPythonObject):
"App::PropertyLength",
"CharacteristicLength",
"MeshRegionProperties",
- "set characteristic length of FEM elements for this region"
+ "set characteristic length of FEM elements for this refinement"
)
obj.addProperty(
"App::PropertyLinkSubList",
"References",
"MeshRegionShapes",
- "List of FEM mesh region shapes"
+ "List of FEM mesh refinement shapes"
)
diff --git a/src/Mod/Fem/femmesh/gmshtools.py b/src/Mod/Fem/femmesh/gmshtools.py
index 0c95b62b18..604ce5db0f 100644
--- a/src/Mod/Fem/femmesh/gmshtools.py
+++ b/src/Mod/Fem/femmesh/gmshtools.py
@@ -444,7 +444,7 @@ class GmshTools():
def get_region_data(self):
# mesh regions
if not self.mesh_obj.MeshRegionList:
- # print(" No mesh regions.")
+ # print(" No mesh refinements.")
pass
else:
# Console.PrintMessage(" Mesh regions, we need to get the elements.\n")
@@ -470,13 +470,13 @@ class GmshTools():
if mr_obj.References:
for sub in mr_obj.References:
# print(sub[0]) # Part the elements belongs to
# check if the shape of the mesh region
# is an element of the Part to mesh
# if not try to find the element in the shape to mesh
search_ele_in_shape_to_mesh = False
if not self.part_obj.Shape.isSame(sub[0].Shape):
Console.PrintLog(
- " One element of the meshregion {} is "
+ " One element of the mesh refinement {} is "
"not an element of the Part to mesh.\n"
"But we are going to try to find it in "
"the Shape to mesh :-)\n"
@@ -509,19 +509,19 @@ class GmshTools():
).Value
else:
Console.PrintError(
- "The element {} of the meshregion {} has "
+ "The element {} of the mesh refinement {} has "
"been added to another mesh region.\n"
.format(elems, mr_obj.Name)
)
else:
Console.PrintError(
- "The meshregion: {} is not used to create the mesh "
+ "The mesh refinement: {} is not used to create the mesh "
"because the reference list is empty.\n"
.format(mr_obj.Name)
)
else:
Console.PrintError(
- "The meshregion: {} is not used to create the "
+ "The mesh refinement: {} is not used to create the "
"mesh because the CharacteristicLength is 0.0 mm.\n"
.format(mr_obj.Name)
)
@@ -948,7 +948,7 @@ class GmshTools():
def outputCompoundWarning(self):
error_message = (
"The mesh to shape is a Boolean Split Tools compound "
- "and the mesh has mesh region list.\n"
+ "and the mesh has mesh refinements list.\n"
"Gmsh could return unexpected meshes in such circumstances.\n"
"If this is the case, use the part workbench and "
"apply a Compound Filter on the compound.\n"
@@ -470,13 +470,13 @@ class GmshTools():
for sub in mr_obj.References:
# print(sub[0]) # Part the elements belongs to
- # check if the shape of the mesh region
+ # check if the shape of the mesh refinements
# is an element of the Part to mesh
# if not try to find the element in the shape to mesh
diff --git a/src/Mod/Fem/femtaskpanels/task_mesh_region.py b/src/Mod/Fem/femtaskpanels/task_mesh_region.py
index e65364345c..d18f2dc311 100644
--- a/src/Mod/Fem/femtaskpanels/task_mesh_region.py
+++ b/src/Mod/Fem/femtaskpanels/task_mesh_region.py
@@ -21,13 +21,13 @@
# * *
# ***************************************************************************
-__title__ = "FreeCAD FEM mesh region task panel for the document object"
+__title__ = "FreeCAD FEM mesh refinement task panel for the document object"
__author__ = "Bernd Hahnebach"
__url__ = "https://www.freecad.org"
## @package task_mesh_region
# \ingroup FEM
# \brief task panel for mesh region object
from PySide import QtCore
@@ -21,13 +21,13 @@
## @package task_mesh_region
# \ingroup FEM
-# \brief task panel for mesh region object
+# \brief task panel for mesh refinement object
from PySide import QtCore